@@ -4,11 +4,12 @@ try:
     from selenium.webdriver.support import expected_conditions as EC
     from selenium.webdriver.common.by import By
     from selenium.common.exceptions import NoSuchElementException,WebDriverException
-    import time
+    from random import randint
+    from selenium.webdriver.common.keys import Keys
     import sys
 except Exception as ex:
     print(ex)
-    
+
 class Utilities:
 
     @staticmethod
@@ -19,10 +20,10 @@ class Utilities:
             driver.quit()
         except Exception as ex:
             print("error at close_driver method : {}".format(ex))
-    
+
     @staticmethod
     def __close_error_popup(driver):
-        '''expects driver's instance as a argument and checks if error shows up 
+        '''expects driver's instance as a argument and checks if error shows up
         like "We could not process your request. Please try again later" ,
         than click on close button to skip that popup.'''
         try:
@@ -34,30 +35,36 @@ class Utilities:
             pass
         except NoSuchElementException:
             pass  #passing this error silently because it may happen that popup never shows up
-        
+
         except Exception as ex:
             #if any other error occured except the above one
             print("error at close_error_popup method : {}".format(ex))
-    
+
     @staticmethod
     def __scroll_down_half(driver):
         try:
-            driver.execute_script("window.scrollTo(0, document.body.scrollHeight / 2);") 
+          driver.execute_script("window.scrollTo(0, document.body.scrollHeight / 2);")
         except Exception as ex:
             #if any error occured than close the driver and exit
             Utilities.__close_driver(driver)
             print("error at scroll_down_half method : {}".format(ex))
 
     @staticmethod
-    def __scroll_down(driver):
+    def __scroll_down(driver,layout):
         """expects driver's instance as a argument, and it scrolls down page to the most bottom till the height"""
         try:
-            driver.execute_script("window.scrollTo(0, document.body.scrollHeight);") 
+          if layout == "old":
+            driver.execute_script(
+                  "window.scrollTo(0, document.body.scrollHeight);")
+          elif layout == "new":
+            body = driver.find_element_by_css_selector("body")
+            for _ in range(randint(2, 3)):
+              body.send_keys(Keys.PAGE_DOWN)
         except Exception as ex:
             #if any error occured than close the driver and exit
             Utilities.__close_driver(driver)
             print("error at scroll_down method : {}".format(ex))
-            
+
     @staticmethod
     def __close_popup(driver):
         """expects driver's instance and closes modal that ask for login, by clicking "Not Now" button """
@@ -75,15 +82,23 @@ class Utilities:
             pass  #passing this exception silently as modal may not show up
         except Exception as ex:
             print("error at close_popup method : {}".format(ex))
-        
+
     @staticmethod
-    def __wait_for_element_to_appear(driver):
+    def __wait_for_element_to_appear(driver,layout):
         """expects driver's instance, wait for posts to show.
         post's CSS class name is userContentWrapper
         """
         try:
-            #wait for page to load so posts are visible
-            WebDriverWait(driver, 30).until(EC.presence_of_element_located((By.CSS_SELECTOR,'.userContentWrapper')))
+            if layout == "old":
+              #wait for page to load so posts are visible
+              body = driver.find_element_by_css_selector("body")
+              for _ in range(randint(3, 5)):
+                body.send_keys(Keys.PAGE_DOWN)
+              WebDriverWait(driver, 30).until(EC.presence_of_element_located((By.CSS_SELECTOR,'.userContentWrapper')))
+            elif layout == "new":
+              WebDriverWait(driver, 30).until(
+                  EC.presence_of_element_located((By.CSS_SELECTOR, "[aria-posinset]")))
+
         except WebDriverException:
             #if it was not found,it means either page is not loading or it does not exists
             print("No posts were found!")
@@ -91,9 +106,9 @@ class Utilities:
             sys.exit(1)  #exit the program, because if posts does not exists,we cannot go further
         except Exception as ex:
             print("error at wait_for_element_to_appear method : {}".format(ex))
-            Utilities.__close_driver(driver) 
-            
-        
+            Utilities.__close_driver(driver)
+
+
 
     @staticmethod
     def __click_see_more(driver,content):
@@ -101,8 +116,8 @@ class Utilities:
         try:
             #find element and click 'see more' button
             element = content.find_element_by_css_selector('span.see_more_link_inner')
-            driver.execute_script("arguments[0].click();", element) #click button using js    
-        
+            driver.execute_script("arguments[0].click();", element) #click button using js
+
         except NoSuchElementException:
             #if it doesn't exists than no need to raise any error
             pass
